@@ -1,20 +1,6 @@
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Nuitka distutils integration.
 
 """
@@ -34,6 +20,11 @@ from nuitka.importing.Importing import (
     flushImportCache,
     locateModule,
 )
+from nuitka.PythonVersions import python_version
+from nuitka.reports.CompilationReportReader import (
+    getEmbeddedDataFilenames,
+    parseCompilationReport,
+)
 from nuitka.Tracing import wheel_logger
 from nuitka.utils.Execution import check_call
 from nuitka.utils.FileOperations import deleteFile, getFileList, renameFile
@@ -44,6 +35,7 @@ def setupNuitkaDistutilsCommands(dist, keyword, value):
     # If the user project setup.py includes the key "build_with_nuitka=True" all
     # build operations (build, bdist_wheel, install etc) will run via Nuitka.
     # pylint: disable=unused-argument
+    # spell-checker: ignore cmdclass
 
     if not value:
         return
@@ -74,7 +66,6 @@ def addToPythonPath(python_path, in_front=False):
 # Class name enforced by distutils, must match the command name.
 # Required by distutils, used as command name, pylint: disable=invalid-name
 class build(distutils.command.build.build):
-
     # pylint: disable=attribute-defined-outside-init
     def run(self):
         wheel_logger.info("Specified packages: %s." % self.distribution.packages)
@@ -93,7 +84,8 @@ class build(distutils.command.build.build):
                         script_module_name = (
                             script_spec.split("=", 1)[1].strip().split(":")[0]
                         )
-                    except Exception as e:  # Catch all the things, pylint: disable=broad-except
+                        # Catch all the things, pylint: disable=broad-except
+                    except Exception as e:
                         wheel_logger.warning(
                             "Problem parsing '%s' script specification in '%s' due to %s"
                             % (script_spec, group, e)
@@ -226,6 +218,9 @@ class build(distutils.command.build.build):
 
     @staticmethod
     def _parseOptionsEntry(option, value):
+        if option == "build_with_nuitka":
+            return
+
         option = "--" + option.lstrip("-")
 
         if type(value) is tuple and len(value) == 2 and value[0] == "setup.py":
@@ -244,7 +239,8 @@ class build(distutils.command.build.build):
             yield "%s=%s" % (option, value)
 
     def _build(self, build_lib):
-        # High complexity, pylint: disable=too-many-branches,too-many-locals
+        # High complexity,
+        # pylint: disable=too-many-branches,too-many-locals,too-many-statements
 
         old_dir = os.getcwd()
 
@@ -262,6 +258,8 @@ class build(distutils.command.build.build):
         # Search in the build directory preferably.
         addMainScriptDirectory(main_package_dir)
 
+        embedded_data_files = set()
+
         for is_package, module_name in self._findBuildTasks():
             # Nuitka wants the main package by filename, probably we should stop
             # needing that.
@@ -278,6 +276,15 @@ class build(distutils.command.build.build):
 
             if package_name is not None:
                 output_dir = os.path.join(build_lib, package_name.asPath())
+
+                # Make sure it's found for compilation which doesn't use the
+                # package location, but pretends its a top level thing, that at
+                # runtime is then loaded more locally.
+                package_part, _include_package_name = module_name.splitModuleBasename()
+
+                addToPythonPath(
+                    os.path.join(main_package_dir, package_part.asPath()), in_front=True
+                )
             else:
                 output_dir = build_lib
 
@@ -285,34 +292,29 @@ class build(distutils.command.build.build):
                 sys.executable,
                 "-m",
                 "nuitka",
-                "--module",
+                "--mode=%s" % ("package" if is_package else "module"),
                 "--enable-plugin=pylint-warnings",
                 "--output-dir=%s" % output_dir,
                 "--nofollow-import-to=*.tests",
+                "--nowarn-mnemonic=compiled-package-hidden-by-package",
                 "--remove-output",
+                # Note: For when we are debugging module mode of Nuitka, not for general use.
+                # "--debug",
+                # "--trace",
+                # "--python-flag=-v"
             ]
 
-            if package_name is not None:
-                package_part, include_package_name = module_name.splitModuleBasename()
-
-                addToPythonPath(
-                    os.path.join(main_package_dir, package_part.asPath()), in_front=True
-                )
-            else:
-                include_package_name = module_name
-
-            if is_package:
-                command.append("--include-package=%s" % include_package_name)
-            else:
-                command.append("--include-module=%s" % include_package_name)
-
-            toml_filename = os.environ.get("NUITKA_TOML_FILE")
+            toml_filename = os.getenv("NUITKA_TOML_FILE")
             if toml_filename:
                 # Import toml parser like "build" module does.
-                try:
-                    from tomli import loads as toml_loads
-                except ImportError:
-                    from toml import loads as toml_loads
+                if python_version >= 0x3B0:
+                    # stdlib only for 3.11, pylint: disable=I0021,import-error
+                    from tomllib import loads as toml_loads
+                else:
+                    try:
+                        from tomli import loads as toml_loads
+                    except ImportError:
+                        from toml import loads as toml_loads
 
                 # Cannot use FileOperations.getFileContents() here, because of non-Nuitka process
                 # pylint: disable=unspecified-encoding
@@ -323,12 +325,30 @@ class build(distutils.command.build.build):
                 for option, value in toml_options.get("nuitka", {}).items():
                     command.extend(self._parseOptionsEntry(option, value))
 
+                for option, value in (
+                    toml_options.get("tool", {}).get("nuitka", {}).items()
+                ):
+                    command.extend(self._parseOptionsEntry(option, value))
+
+            report_filename = None
+
             # Process any extra options from setuptools
             if "nuitka" in self.distribution.command_options:
                 for option, value in self.distribution.command_options[
                     "nuitka"
                 ].items():
-                    command.extend(self._parseOptionsEntry(option, value))
+                    for option in self._parseOptionsEntry(option, value):
+                        command.append(option)
+
+                        if option.startswith("--report="):
+                            report_filename = option.split("=", 1)[1]
+
+            if report_filename is None:
+                command.append("--report=compilation-report.xml")
+                report_filename = "compilation-report.xml"
+                delete_report = True
+            else:
+                delete_report = False
 
             command.append(main_filename)
 
@@ -341,26 +361,35 @@ class build(distutils.command.build.build):
                 "Finished compilation of '%s'." % module_name.asString(), style="green"
             )
 
+            report = parseCompilationReport(report_filename)
+
+            embedded_data_files.update(getEmbeddedDataFilenames(report))
+
+            if delete_report:
+                os.unlink(report_filename)
+
         self.build_lib = build_lib
 
-        os.chdir(old_dir)
-
         # Remove Python code from build folder, that's our job now.
-        for root, _, filenames in os.walk(build_lib):
-            for filename in filenames:
-                fullpath = os.path.join(root, filename)
+        for filename in getFileList(
+            build_lib, only_suffixes=(".py", ".pyw", ".pyc", ".pyo")
+        ):
+            os.unlink(filename)
 
-                if fullpath.lower().endswith((".py", ".pyw", ".pyc", ".pyo")):
-                    os.unlink(fullpath)
+        # Remove data files from build folder, that's our job now too
+        for filename in embedded_data_files:
+            os.unlink(filename)
+
+        os.chdir(old_dir)
 
 
 # Required by distutils, used as command name, pylint: disable=invalid-name
 class install(distutils.command.install.install):
-
     # pylint: disable=attribute-defined-outside-init
     def finalize_options(self):
         distutils.command.install.install.finalize_options(self)
-        # Ensure the purelib folder is not used
+        # Ensure the "purelib" folder is not used
+        # spell-checker: ignore purelib,platlib
         self.install_lib = self.install_platlib
 
 
@@ -380,8 +409,8 @@ class bdist_nuitka(wheel.bdist_wheel.bdist_wheel):
         wheel.bdist_wheel.bdist_wheel.finalize_options(self)
         # Force module to use correct platform in name
         self.root_is_pure = False
-        self.plat_name_supplied = self.plat_name is not None
 
+    # virtual method name, spell-checker: ignore wheelfile
     def write_wheelfile(self, wheelfile_base, generator=None):
         if generator is None:
             from nuitka.Version import getNuitkaVersion
@@ -391,3 +420,19 @@ class bdist_nuitka(wheel.bdist_wheel.bdist_wheel):
         wheel.bdist_wheel.bdist_wheel.write_wheelfile(
             self, wheelfile_base=wheelfile_base, generator=generator
         )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
