@@ -1,20 +1,6 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ These are just helpers to create nodes, often to replace existing nodes
 
 These are for use in optimizations and computations, and therefore cover
@@ -43,16 +29,18 @@ def makeConstantReplacementNode(constant, node, user_provided):
 
 
 def makeRaiseExceptionReplacementExpression(
-    expression, exception_type, exception_value
+    expression, exception_type, exception_value, no_warning=False
 ):
-    from .BuiltinRefNodes import ExpressionBuiltinExceptionRef
-    from .ExceptionNodes import ExpressionRaiseException
+    from .ExceptionNodes import (
+        ExpressionRaiseException,
+        makeBuiltinMakeExceptionNode,
+    )
 
     source_ref = expression.source_ref
 
     assert type(exception_type) is str
 
-    if Options.shallWarnImplicitRaises():
+    if not no_warning and Options.shallWarnImplicitRaises():
         unusual_logger.warning(
             '%s: Will always raise exception: "%s(%s)"'
             % (
@@ -62,12 +50,22 @@ def makeRaiseExceptionReplacementExpression(
             )
         )
 
+    if type(exception_value) is not tuple:
+        exception_value = (exception_value,)
+
+    args = tuple(
+        makeConstantReplacementNode(
+            constant=element, node=expression, user_provided=False
+        )
+        for element in exception_value
+    )
+
     result = ExpressionRaiseException(
-        exception_type=ExpressionBuiltinExceptionRef(
-            exception_name=exception_type, source_ref=source_ref
-        ),
-        exception_value=makeConstantReplacementNode(
-            constant=exception_value, node=expression, user_provided=False
+        exception_type=makeBuiltinMakeExceptionNode(
+            exception_name=exception_type,
+            args=args,
+            for_raise=False,
+            source_ref=source_ref,
         ),
         source_ref=source_ref,
     )
@@ -75,15 +73,19 @@ def makeRaiseExceptionReplacementExpression(
     return result
 
 
-def makeRaiseExceptionReplacementStatement(statement, exception_type, exception_value):
-    from .BuiltinRefNodes import ExpressionBuiltinExceptionRef
-    from .ExceptionNodes import StatementRaiseExceptionImplicit
+def makeRaiseExceptionReplacementStatement(
+    statement, exception_type, exception_value, no_warning=False
+):
+    from .ExceptionNodes import (
+        StatementRaiseException,
+        makeBuiltinMakeExceptionNode,
+    )
 
     source_ref = statement.getSourceReference()
 
     assert type(exception_type) is str
 
-    if Options.shallWarnImplicitRaises():
+    if not no_warning and Options.shallWarnImplicitRaises():
         unusual_logger.warning(
             '%s: Will always raise exception: "%s(%s)"'
             % (
@@ -93,13 +95,18 @@ def makeRaiseExceptionReplacementStatement(statement, exception_type, exception_
             )
         )
 
-    result = StatementRaiseExceptionImplicit(
-        exception_type=ExpressionBuiltinExceptionRef(
-            exception_name=exception_type, source_ref=source_ref
-        ),
-        exception_value=makeConstantReplacementNode(
-            constant=exception_value, node=statement, user_provided=False
+    result = StatementRaiseException(
+        exception_type=makeBuiltinMakeExceptionNode(
+            exception_name=exception_type,
+            args=(
+                makeConstantReplacementNode(
+                    constant=exception_value, node=statement, user_provided=False
+                ),
+            ),
+            for_raise=False,
+            source_ref=source_ref,
         ),
+        exception_value=None,
         exception_cause=None,
         exception_trace=None,
         source_ref=source_ref,
@@ -111,41 +118,35 @@ def makeRaiseExceptionReplacementStatement(statement, exception_type, exception_
 def makeRaiseExceptionReplacementExpressionFromInstance(expression, exception):
     assert isinstance(exception, Exception)
 
-    args = exception.args
-    if type(args) is tuple and len(args) == 1:
-        value = args[0]
-    else:
-        assert type(args) is tuple
-        value = args
-
     return makeRaiseExceptionReplacementExpression(
         expression=expression,
         exception_type=exception.__class__.__name__,
-        exception_value=value,
+        exception_value=exception.args,
     )
 
 
 def makeRaiseExceptionStatementFromInstance(exception, source_ref):
     assert isinstance(exception, Exception)
 
-    args = exception.args
-    if type(args) is tuple and len(args) == 1:
-        value = args[0]
-    else:
-        assert type(args) is tuple
-        value = args
-
-    from .BuiltinRefNodes import ExpressionBuiltinExceptionRef
     from .ConstantRefNodes import makeConstantRefNode
-    from .ExceptionNodes import StatementRaiseExceptionImplicit
+    from .ExceptionNodes import (
+        StatementRaiseException,
+        makeBuiltinMakeExceptionNode,
+    )
 
-    return StatementRaiseExceptionImplicit(
-        exception_type=ExpressionBuiltinExceptionRef(
-            exception_name=exception.__class__.__name__, source_ref=source_ref
-        ),
-        exception_value=makeConstantRefNode(
-            constant=value, source_ref=source_ref, user_provided=False
+    args_value = tuple(
+        makeConstantRefNode(constant=arg, source_ref=source_ref, user_provided=False)
+        for arg in exception.args
+    )
+
+    return StatementRaiseException(
+        exception_type=makeBuiltinMakeExceptionNode(
+            exception_name=exception.__class__.__name__,
+            args=args_value,
+            for_raise=False,
+            source_ref=source_ref,
         ),
+        exception_value=None,
         exception_cause=None,
         exception_trace=None,
         source_ref=source_ref,
@@ -155,10 +156,12 @@ def makeRaiseExceptionStatementFromInstance(exception, source_ref):
 def makeRaiseExceptionExpressionFromTemplate(
     exception_type, template, template_args, source_ref
 ):
-    from .BuiltinRefNodes import ExpressionBuiltinExceptionRef
     from .ConstantRefNodes import makeConstantRefNode
     from .ContainerMakingNodes import makeExpressionMakeTupleOrConstant
-    from .ExceptionNodes import ExpressionRaiseException
+    from .ExceptionNodes import (
+        ExpressionRaiseException,
+        makeBuiltinMakeExceptionNode,
+    )
     from .OperatorNodes import makeBinaryOperationNode
 
     if type(template_args) is tuple:
@@ -167,15 +170,19 @@ def makeRaiseExceptionExpressionFromTemplate(
         )
 
     return ExpressionRaiseException(
-        exception_type=ExpressionBuiltinExceptionRef(
-            exception_name=exception_type, source_ref=source_ref
-        ),
-        exception_value=makeBinaryOperationNode(
-            operator="Mod",
-            left=makeConstantRefNode(
-                constant=template, source_ref=source_ref, user_provided=True
+        exception_type=makeBuiltinMakeExceptionNode(
+            exception_name=exception_type,
+            args=(
+                makeBinaryOperationNode(
+                    operator="Mod",
+                    left=makeConstantRefNode(
+                        constant=template, source_ref=source_ref, user_provided=True
+                    ),
+                    right=template_args,
+                    source_ref=source_ref,
+                ),
             ),
-            right=template_args,
+            for_raise=False,
             source_ref=source_ref,
         ),
         source_ref=source_ref,
@@ -313,14 +320,14 @@ def mergeStatements(statements, allow_none=False):
             pass
         elif type(statement) in (tuple, list):
             merged_statements += mergeStatements(statement, allow_none)
-        elif statement.isStatement() or statement.isStatementsFrame():
+        elif statement.isStatementsFrame():
             merged_statements.append(statement)
         elif statement.isStatementsSequence():
             merged_statements.extend(mergeStatements(statement.subnode_statements))
         else:
-            assert False, statement
+            merged_statements.append(statement)
 
-    return merged_statements
+    return tuple(merged_statements)
 
 
 def makeStatementsSequenceReplacementNode(statements, node):
@@ -331,18 +338,7 @@ def makeStatementsSequenceReplacementNode(statements, node):
     )
 
 
-def convertNoneConstantToNone(node):
-    if node is None:
-        return None
-    elif node.isExpressionConstantNoneRef():
-        return None
-    else:
-        return node
-
-
 def wrapExpressionWithSideEffects(side_effects, old_node, new_node):
-    assert new_node.isExpression()
-
     from .SideEffectNodes import ExpressionSideEffects
 
     if side_effects:
@@ -467,3 +463,19 @@ def makeRaiseImportErrorReplacementExpression(expression, module_name):
         exception_type="ImportError",
         exception_value=module_name.asString(),
     )
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
