@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Collection of information for reports and their writing.
@@ -20,6 +20,7 @@ from nuitka.code_generation.ConstantCodes import getDistributionMetadataValues
 from nuitka.containers.OrderedSets import OrderedSet
 from nuitka.freezer.IncludedDataFiles import getIncludedDataFiles
 from nuitka.freezer.IncludedEntryPoints import getStandaloneEntryPoints
+from nuitka.freezer.Standalone import getRemovedUsedDllsInfo
 from nuitka.importing.Importing import getPackageSearchPath
 from nuitka.importing.Recursion import getRecursionDecisions
 from nuitka.ModuleRegistry import (
@@ -29,10 +30,13 @@ from nuitka.ModuleRegistry import (
     getModuleOptimizationTimingInfos,
 )
 from nuitka.Options import (
+    getCompilationMode,
     getCompilationReportFilename,
     getCompilationReportTemplates,
     getCompilationReportUserData,
+    getOnefileTempDirSpec,
     isOnefileMode,
+    isOnefileTempDirMode,
     shallCreateDiffableCompilationReport,
 )
 from nuitka.OutputDirectories import (
@@ -45,6 +49,8 @@ from nuitka.PythonFlavors import getPythonFlavorName
 from nuitka.PythonVersions import (
     getLaunchingSystemPrefixPath,
     getSystemPrefixPath,
+    isPythonWithGil,
+    python_version,
     python_version_full_str,
 )
 from nuitka.Tracing import ReportingSystemExit, reports_logger
@@ -54,6 +60,7 @@ from nuitka.utils.Distributions import (
     getDistributionName,
     getDistributionsFromModuleName,
     getDistributionVersion,
+    isDistributionVendored,
 )
 from nuitka.utils.FileOperations import (
     getReportPath,
@@ -159,6 +166,14 @@ def _getReportInputData(aborted):
         for dist in all_distributions
     )
 
+    module_distribution_vendored = dict(
+        (
+            getDistributionName(dist),
+            isDistributionVendored(getDistributionName(dist)),
+        )
+        for dist in all_distributions
+    )
+
     module_exclusions = dict((module.getFullName(), {}) for module in getDoneModules())
 
     # TODO: The module filename, and other things can be None. Once we change to
@@ -201,10 +216,15 @@ def _getReportInputData(aborted):
     python_exe = sys.executable
 
     python_flavor = getPythonFlavorName()
+
+    # We want that name though, we started using it before
+    # pylint: disable=redefined-outer-name
     python_version = python_version_full_str
     os_name = getOS()
     arch_name = getArchitecture()
 
+    gil = isPythonWithGil()
+
     # Record system encoding, spell-checker: ignore getfilesystemencoding
     filesystem_encoding = sys.getfilesystemencoding()
 
@@ -239,6 +259,8 @@ def _getReportInputData(aborted):
         scons_error_report_data = {}
         output_run_filename = "failed too early"
 
+    compilation_mode = getCompilationMode()
+
     return dict(
         (var_name, var_value)
         for var_name, var_value in locals().items()
@@ -316,7 +338,12 @@ def _addModulesToReport(root, report_input_data, diffable):
                     )
                 influence_xml_node.attrib["result"] = str(condition_result).lower()
             elif influence == "variable-used":
-                variable_name, condition_tags_used, variable_value = detail
+                (
+                    variable_name,
+                    condition_tags_used,
+                    variable_value,
+                    config_module_name,
+                ) = detail
 
                 influence_xml_node.attrib["variable"] = variable_name
                 if condition_tags_used:
@@ -324,6 +351,10 @@ def _addModulesToReport(root, report_input_data, diffable):
                         condition_tags_used
                     )
                 influence_xml_node.attrib["value"] = variable_value
+
+                if module_name != config_module_name:
+                    influence_xml_node.attrib["config_module"] = config_module_name
+
             elif influence == "parameter-used":
                 parameter_name, condition_tags_used, parameter_value = detail
 
@@ -508,6 +539,7 @@ def writeCompilationReport(report_filename, report_input_data, diffable):
         "nuitka-compilation-report",
         nuitka_version=report_input_data["nuitka_version"],
         nuitka_commercial_version=report_input_data["nuitka_commercial_version"],
+        mode=report_input_data["compilation_mode"],
         completion=completion,
     )
 
@@ -640,6 +672,16 @@ def writeCompilationReport(report_filename, report_input_data, diffable):
             # TODO: No reason yet.
         )
 
+    for standalone_entry_point, (reason, removed_dll_paths) in getRemovedUsedDllsInfo():
+        for removed_dll_path in removed_dll_paths:
+            TreeXML.appendTreeElement(
+                root,
+                "excluded_dll",
+                name=_getCompilationReportPath(removed_dll_path),
+                used_by=standalone_entry_point.dest_path,
+                reason=reason,
+            )
+
     if not diffable:
         data_composer_values = getDataComposerReportValues()
 
@@ -690,13 +732,21 @@ def writeCompilationReport(report_filename, report_input_data, diffable):
             user_enabled="no" if plugin.isAlwaysEnabled() else "yes",
         )
 
+    if isOnefileMode():
+        _onefile_xml_node = TreeXML.appendTreeElement(
+            root,
+            "onefile",
+            cache_mode="temporary" if isOnefileTempDirMode() else "cached",
+            unpack_dir=getOnefileTempDirSpec(),
+        )
+
     distributions_xml_node = TreeXML.appendTreeElement(
         root,
         "distributions",
     )
 
     for distribution in report_input_data["all_distributions"]:
-        TreeXML.appendTreeElement(
+        distribution_node = TreeXML.appendTreeElement(
             distributions_xml_node,
             "distribution",
             name=getDistributionName(distribution),
@@ -706,6 +756,11 @@ def writeCompilationReport(report_filename, report_input_data, diffable):
             ],
         )
 
+        if report_input_data["module_distribution_vendored"][
+            getDistributionName(distribution)
+        ]:
+            distribution_node.attrib["vendored"] = "yes"
+
     python_xml_node = TreeXML.appendTreeElement(
         root,
         "python",
@@ -718,6 +773,9 @@ def writeCompilationReport(report_filename, report_input_data, diffable):
         filesystem_encoding=report_input_data["filesystem_encoding"],
     )
 
+    if python_version >= 0x3D0:
+        python_xml_node.attrib["gil"] = "yes" if report_input_data["gil"] else "no"
+
     search_path = getPackageSearchPath(None)
 
     if search_path is not None:
