@@ -1,20 +1,6 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Part of "Nuitka", an optimizing Python compiler that is compatible and
-#     integrates with CPython, but also works on its own.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
+
 """ Reformulation of with statements.
 
 Consult the Developer Manual for information. TODO: Add ability to sync
@@ -23,10 +9,8 @@ source code comments with Developer Manual sections.
 """
 
 from nuitka import Options
-from nuitka.nodes.AttributeNodes import (
-    ExpressionAttributeLookupSpecial,
-    makeExpressionAttributeLookup,
-)
+from nuitka.nodes.AttributeLookupNodes import ExpressionAttributeLookupSpecial
+from nuitka.nodes.AttributeNodes import makeExpressionAttributeLookup
 from nuitka.nodes.CallNodes import (
     ExpressionCallEmpty,
     ExpressionCallNoKeywords,
@@ -50,15 +34,17 @@ from nuitka.nodes.StatementNodes import (
 )
 from nuitka.nodes.VariableAssignNodes import makeStatementAssignmentVariable
 from nuitka.nodes.VariableRefNodes import ExpressionTempVariableRef
-from nuitka.nodes.VariableReleaseNodes import makeStatementReleaseVariable
-from nuitka.nodes.YieldNodes import ExpressionYieldFromWaitable
+from nuitka.nodes.YieldNodes import ExpressionYieldFromAwaitable
 from nuitka.PythonVersions import python_version
 
 from .ReformulationAssignmentStatements import buildAssignmentStatements
 from .ReformulationTryExceptStatements import (
     makeTryExceptSingleHandlerNodeWithPublish,
 )
-from .ReformulationTryFinallyStatements import makeTryFinallyStatement
+from .ReformulationTryFinallyStatements import (
+    makeTryFinallyReleaseStatement,
+    makeTryFinallyStatement,
+)
 from .TreeHelpers import (
     buildNode,
     buildStatementsNode,
@@ -77,13 +63,13 @@ def _buildWithNode(provider, context_expr, assign_target, body, sync, source_ref
     temp_scope = provider.allocateTempScope("with")
 
     tmp_source_variable = provider.allocateTempVariable(
-        temp_scope=temp_scope, name="source"
+        temp_scope=temp_scope, name="source", temp_type="object"
     )
     tmp_exit_variable = provider.allocateTempVariable(
-        temp_scope=temp_scope, name="exit"
+        temp_scope=temp_scope, name="exit", temp_type="object"
     )
     tmp_enter_variable = provider.allocateTempVariable(
-        temp_scope=temp_scope, name="enter"
+        temp_scope=temp_scope, name="enter", temp_type="object"
     )
 
     # Indicator variable, will end up with C bool type, and need not be released.
@@ -166,13 +152,13 @@ def _buildWithNode(provider, context_expr, assign_target, body, sync, source_ref
 
     # For "async with", await the entered value and exit value must be awaited.
     if not sync:
-        exit_value_exception = ExpressionYieldFromWaitable(
+        exit_value_exception = ExpressionYieldFromAwaitable(
             expression=ExpressionAsyncWaitExit(
                 expression=exit_value_exception, source_ref=source_ref
             ),
             source_ref=source_ref,
         )
-        exit_value_no_exception = ExpressionYieldFromWaitable(
+        exit_value_no_exception = ExpressionYieldFromAwaitable(
             ExpressionAsyncWaitExit(
                 expression=exit_value_no_exception, source_ref=source_ref
             ),
@@ -188,7 +174,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, sync, source_ref
 
     # Before 3.9, __aenter__ is immediately awaited, after we first do __aexit__ lookup.
     if not sync and python_version < 0x390:
-        enter_value = ExpressionYieldFromWaitable(
+        enter_value = ExpressionYieldFromAwaitable(
             expression=ExpressionAsyncWaitEnter(
                 expression=enter_value, source_ref=source_ref
             ),
@@ -219,7 +205,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, sync, source_ref
     if python_version >= 0x390 and not sync:
         enter_await_statement = makeStatementAssignmentVariable(
             variable=tmp_enter_variable,
-            source=ExpressionYieldFromWaitable(
+            source=ExpressionYieldFromAwaitable(
                 expression=ExpressionAsyncWaitEnter(
                     expression=ExpressionTempVariableRef(
                         variable=tmp_enter_variable, source_ref=source_ref
@@ -301,19 +287,13 @@ def _buildWithNode(provider, context_expr, assign_target, body, sync, source_ref
         ),
     )
 
-    return makeTryFinallyStatement(
+    return makeTryFinallyReleaseStatement(
         provider=provider,
         tried=statements,
-        final=(
-            makeStatementReleaseVariable(
-                variable=tmp_source_variable, source_ref=with_exit_source_ref
-            ),
-            makeStatementReleaseVariable(
-                variable=tmp_enter_variable, source_ref=with_exit_source_ref
-            ),
-            makeStatementReleaseVariable(
-                variable=tmp_exit_variable, source_ref=with_exit_source_ref
-            ),
+        variables=(
+            tmp_source_variable,
+            tmp_enter_variable,
+            tmp_exit_variable,
         ),
         source_ref=source_ref,
     )
@@ -324,13 +304,13 @@ def buildWithNode(provider, node, source_ref):
     # manual. Catches exceptions, and provides them to "__exit__", while making
     # the "__enter__" value available under a given name.
 
-    # Before Python3.3, multiple context managers are not visible in the parse
+    # Before Python3, multiple context managers are not visible in the parse
     # tree, now we need to handle it ourselves.
     if hasattr(node, "items"):
         context_exprs = [item.context_expr for item in node.items]
         assign_targets = [item.optional_vars for item in node.items]
     else:
-        # Make it a list for before Python3.3
+        # Make it a list for before Python3
         context_exprs = [node.context_expr]
         assign_targets = [node.optional_vars]
 
@@ -360,7 +340,7 @@ def buildAsyncWithNode(provider, node, source_ref):
     # manual. Catches exceptions, and provides them to "__exit__", while making
     # the "__enter__" value available under a given name.
 
-    # Before Python3.3, multiple context managers are not visible in the parse
+    # Before Python3, multiple context managers are not visible in the parse
     # tree, now we need to handle it ourselves.
     context_exprs = [item.context_expr for item in node.items]
     assign_targets = [item.optional_vars for item in node.items]
@@ -384,3 +364,19 @@ def buildAsyncWithNode(provider, node, source_ref):
         )
 
     return body
+
+
+#     Part of "Nuitka", an optimizing Python compiler that is compatible and
+#     integrates with CPython, but also works on its own.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
