@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Runner for plugins tests of Nuitka.
@@ -21,17 +21,19 @@ sys.path.insert(
 
 # isort:start
 
+from nuitka.containers.OrderedDicts import OrderedDict
 from nuitka.tools.testing.Common import (
+    checkTestRequirements,
     compareWithCPython,
     createSearchMode,
     getMainProgramFilename,
     my_print,
     reportSkip,
+    scanDirectoryForTestCases,
     setup,
     withPythonPathChange,
 )
 from nuitka.utils.Utils import isWin32Windows
-from nuitka.Version import getCommercialVersion
 
 
 def main():
@@ -41,14 +43,7 @@ def main():
     search_mode = createSearchMode()
 
     # TODO: Add a directory test case scanner instead of duplicating this kind of code.
-    for filename in sorted(os.listdir(".")):
-        if (
-            not os.path.isdir(filename)
-            or filename.endswith(".build")
-            or filename.endswith(".dist")
-        ):
-            continue
-
+    for filename in scanDirectoryForTestCases(dirname=".", cases_are_directories=True):
         filename = os.path.relpath(filename)
 
         extra_flags = ["expect_success"]
@@ -58,36 +53,48 @@ def main():
 
         active = search_mode.consider(dirname=None, filename=filename)
 
-        if active:
-            my_print("Consider output of recursively compiled program:", filename)
+        if not active:
+            continue
 
-            if filename in ("code_signing",):
-                if getCommercialVersion() is None:
-                    reportSkip(
-                        "Plugin only available in Nuitka commercial", ".", filename
-                    )
-                    continue
+        # skip each test if their respective requirements are not met
+        requirements_met, error_message = checkTestRequirements(filename)
+        if not requirements_met:
+            reportSkip(error_message, ".", filename)
+            continue
 
-                if not isWin32Windows():
-                    reportSkip("Plugin only works on Windows", ".", filename)
-                    continue
+        my_print("Consider output of recursively compiled program:", filename)
 
-            filename_main = getMainProgramFilename(filename)
+        if filename in ("code_signing_commercial",):
+            if not isWin32Windows():
+                reportSkip("Plugin only works on Windows", ".", filename)
+                continue
 
-            extra_python_path = [
-                os.path.abspath(os.path.join(filename, entry))
-                for entry in os.listdir(filename)
-                if entry.startswith("path")
-            ]
+        filename_main = getMainProgramFilename(filename)
 
-            with withPythonPathChange(extra_python_path):
-                compareWithCPython(
-                    dirname=filename,
-                    filename=filename_main,
-                    extra_flags=extra_flags,
-                    search_mode=search_mode,
-                    needs_2to3=False,
+        # TODO: Push this into extra_flags at some point.
+        extra_python_path = [
+            os.path.abspath(os.path.join(filename, entry))
+            for entry in os.listdir(filename)
+            if entry.startswith("path")
+        ]
+
+        if filename == "output_encryption_commercial":
+            extra_flags = OrderedDict(
+                (
+                    ("", extra_flags),
+                    ("stderr", extra_flags),
+                    ("stdout", extra_flags),
+                    ("stdout+stderr", extra_flags),
                 )
+            )
+
+        with withPythonPathChange(extra_python_path):
+            compareWithCPython(
+                dirname=filename,
+                filename=filename_main,
+                extra_flags=extra_flags,
+                search_mode=search_mode,
+            )
 
     search_mode.finish()
 
