@@ -1,21 +1,6 @@
 #!/usr/bin/env python
-#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
-#
-#     Python tests originally created or extracted from other peoples work. The
-#     parts were too small to be protected.
-#
-#     Licensed under the Apache License, Version 2.0 (the "License");
-#     you may not use this file except in compliance with the License.
-#     You may obtain a copy of the License at
-#
-#        http://www.apache.org/licenses/LICENSE-2.0
-#
-#     Unless required by applicable law or agreed to in writing, software
-#     distributed under the License is distributed on an "AS IS" BASIS,
-#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#     See the License for the specific language governing permissions and
-#     limitations under the License.
-#
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+
 
 """ Runner for program tests of Nuitka.
 
@@ -39,6 +24,7 @@ sys.path.insert(
 
 # isort:start
 
+from nuitka.containers.OrderedDicts import OrderedDict
 from nuitka.tools.testing.Common import (
     checkTestRequirements,
     compareWithCPython,
@@ -138,16 +124,14 @@ def main():
             )
         elif filename == "reimport_main_dynamic":
             if python_version < (3,):
-                os.environ[
-                    "NUITKA_EXTRA_OPTIONS"
-                ] = extra_options + " --include-plugin-directory=%s" % (
-                    os.path.abspath(filename)
+                os.environ["NUITKA_EXTRA_OPTIONS"] = (
+                    extra_options
+                    + " --include-plugin-directory=%s" % (os.path.abspath(filename))
                 )
             else:
-                os.environ[
-                    "NUITKA_EXTRA_OPTIONS"
-                ] = extra_options + " --include-plugin-files=%s/*.py" % (
-                    os.path.abspath(filename)
+                os.environ["NUITKA_EXTRA_OPTIONS"] = (
+                    extra_options
+                    + " --include-plugin-files=%s/*.py" % (os.path.abspath(filename))
                 )
 
             extra_flags.append("ignore_warnings")
@@ -181,23 +165,32 @@ def main():
             compareWithCPython(
                 dirname=filename,
                 filename=filename_main,
-                extra_flags=extra_flags,
+                extra_flags=OrderedDict(
+                    (
+                        ("", extra_flags),
+                        ("variant", extra_flags + extra_variant),
+                    )
+                ),
                 search_mode=search_mode,
-                needs_2to3=False,
             )
 
-            if extra_variant:
-                my_print("Extra variation %r." % extra_variant)
-                compareWithCPython(
-                    dirname=filename,
-                    filename=filename_main,
-                    extra_flags=extra_flags + extra_variant,
-                    search_mode=search_mode,
-                    needs_2to3=False,
-                )
-
     search_mode.finish()
 
 
 if __name__ == "__main__":
     main()
+
+#     Python tests originally created or extracted from other peoples work. The
+#     parts were too small to be protected.
+#
+#     Licensed under the Apache License, Version 2.0 (the "License");
+#     you may not use this file except in compliance with the License.
+#     You may obtain a copy of the License at
+#
+#        http://www.apache.org/licenses/LICENSE-2.0
+#
+#     Unless required by applicable law or agreed to in writing, software
+#     distributed under the License is distributed on an "AS IS" BASIS,
+#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#     See the License for the specific language governing permissions and
+#     limitations under the License.
